==> portal-contribuinte-3.081.2.zip: BOOT-INF/classes/sql/simam/estornoArrecadacaoCreditoCargaExistente.sql <==
select x.idtcearrtipocreditoest,
       x.nrAnoArrecadacao,
       x.nrCredito,
       x.nranocredito,
       x.nrdivida,
       x.nranodivida,
       x.nrMes,
       x.nrAno,
       x.dtestorno,
       sum(x.valor) as valor
from (
select atc.idtcearrtipocreditoest,
       atc.nrAnoArrecadacao,
       tlc.nrcredito,
       tlc.nranocredito,
       tid.nrdivida,
       tid.nranodivida,
       extract(month from tpag.datacredito) as nrMes,
       extract(year  from tpag.datacredito) as nrAno,
       atc.dtestorno,
       tpd.valorpago as valor
from tceArrecadacaoTipoCreditoEst          atc
join tceArrTipoCreditoPagamentoest         atcp on atcp.idtcearrtipocreditoest = atc.idtcearrtipocreditoest
left join tribpagamentodebito           tpd  on tpd.iddebitoparcelareceita = atcp.iddebitoparcelareceita and tpd.idpagamentobloqueto = atcp.idpagamentobloqueto
left join tribpagamentobloqueto         tpb  on tpb.idpagamentobloqueto  = atcp.idpagamentobloqueto
left join tribpagamento                 tpag on tpag.entidade = tpb.entidade and tpag.exerciciopagamento = tpb.exerciciopagamento and tpag.pagamento = tpb.pagamento
left join tcedebitolanccredito          tdlc on tdlc.iddebitoparcelareceita = atcp.iddebitoparcelareceita
left join tcelanccredito                tlc  on tlc.idtcelanccredito = tdlc.idtcelanccredito
left join (select distinct a.idtceinsccreditoda, a.iddebitoparcelareceitadestino from tcedebitoinsccreditoda a) tdic on tdic.iddebitoparcelareceitaDestino = atcp.iddebitoparcelareceita
left join tceinsccreditoda              tid  on tid.idtceinsccreditoda = tdic.idtceinsccreditoda
where tpag.entidade = :entidade and tpag.datacredito BETWEEN :dataInicial AND :dataFinal
union all
select atc.idtcearrtipocreditoest,
       atc.nrAnoArrecadacao,
       tlc.nrcredito,
       tlc.nranocredito,
       tid.nrdivida,
       tid.nranodivida,
       extract(month from tcc.datacredito) as nrMes,
       extract(year  from tcc.datacredito) as nrAno,
       atc.dtestorno,
       tcci.valorlancado as valor
from tceArrecadacaoTipoCreditoEst          atc
left join tceArrTipoCreditoCreditoEst      atcc on atcc.idtcearrtipocreditoest = atc.idtcearrtipocreditoest
left join tribCreditoContribuinteItem   tcci on tcci.idcreditocontribuinteitem = atcc.idcreditocontribuinteitem and tcci.iddebitoparcelareceita = atcc.iddebitoparcelareceita
left join tribcreditocontribuinte       tcc  on tcc.entidade = tcci.entidade and tcc.exercicio = tcci.exercicio and tcc.creditocontribuinte = tcci.creditocontribuinte
left join tribdebitoparcelareceita      tdpr on tdpr.iddebitoparcelareceita  = tcci.iddebitoparcelareceita
left join tribdebitoparcela             tdp  on tdp.entidade = tdpr.entidade and tdp.exercicio = tdpr.exercicio and tdp.tipocadastro = tdpr.tipocadastro
                                            and tdp.cadastrogeral = tdpr.cadastrogeral and tdp.guiarecolhimento = tdpr.guiarecolhimento
                                            and tdp.subdivida = tdpr.subdivida and tdp.parcela = tdpr.parcela
left join tcedebitolanccreditoEst          tdlc on tdlc.iddebitoparcelareceita = atcc.iddebitoparcelareceita
left join tcelanccreditoEst                tlc  on tlc.idtcelanccreditoest = tdlc.idtcelanccreditoest
left join (select distinct a.idtceinsccreditodaest, a.iddebitoparcelareceita from tcedebitoinsccreditodaest a) tdic on tdic.iddebitoparcelareceita = atcc.iddebitoparcelareceita
left join tceinsccreditodaEst              tid  on tid.idtceinsccreditodaest = tdic.idtceinsccreditodaest
where tcc.entidade = :entidade and tcc.datacredito between :dataInicial and :dataFinal
) x
group by x.idtcearrtipocreditoest,
       x.nrAnoArrecadacao,
       x.nrCredito,
       x.nranocredito,
       x.nrdivida,
       x.nranodivida,
       x.nrMes,
       x.nrAno,
       x.dtestorno
order by 2,1

==> portal-contribuinte-3.096.2.zip: BOOT-INF/classes/sql/simam/estornoArrecadacaoCreditoCargaExistente.sql <==
select x.idtcearrtipocreditoest,
       x.nrAnoArrecadacao,
       x.nrCredito,
       x.nranocredito,
       x.nrdivida,
       x.nranodivida,
       x.nrMes,
       x.nrAno,
       x.dtestorno,
       sum(x.valor) as valor
from (
select atc.idtcearrtipocreditoest,
       atc.nrAnoArrecadacao,
       tlc.nrcredito,
       tlc.nranocredito,
       tid.nrdivida,
       tid.nranodivida,
       extract(month from tpag.datacredito) as nrMes,
       extract(year  from tpag.datacredito) as nrAno,
       atc.dtestorno,
       tpd.valorpago as valor
from tceArrecadacaoTipoCreditoEst          atc
join tceArrTipoCreditoPagamentoest         atcp on atcp.idtcearrtipocreditoest = atc.idtcearrtipocreditoest
left join tribpagamentodebito           tpd  on tpd.iddebitoparcelareceita = atcp.iddebitoparcelareceita and tpd.idpagamentobloqueto = atcp.idpagamentobloqueto
left join tribpagamentobloqueto         tpb  on tpb.idpagamentobloqueto  = atcp.idpagamentobloqueto
left join tribpagamento                 tpag on tpag.entidade = tpb.entidade and tpag.exerciciopagamento = tpb.exerciciopagamento and tpag.pagamento = tpb.pagamento
left join tcedebitolanccredito          tdlc on tdlc.iddebitoparcelareceita = atcp.iddebitoparcelareceita
left join tcelanccredito                tlc  on tlc.idtcelanccredito = tdlc.idtcelanccredito
left join (select distinct a.idtceinsccreditoda, a.iddebitoparcelareceita from tcedebitoinsccreditoda a) tdic on tdic.iddebitoparcelareceita = atcp.iddebitoparcelareceita
left join tceinsccreditoda              tid  on tid.idtceinsccreditoda = tdic.idtceinsccreditoda
where tpag.entidade = :entidade and tpag.datacredito BETWEEN :dataInicial AND :dataFinal
union all
select atc.idtcearrtipocreditoest,
       atc.nrAnoArrecadacao,
       tlc.nrcredito,
       tlc.nranocredito,
       tid.nrdivida,
       tid.nranodivida,
       extract(month from tcc.datacredito) as nrMes,
       extract(year  from tcc.datacredito) as nrAno,
       atc.dtestorno,
       tcci.valorlancado as valor
from tceArrecadacaoTipoCreditoEst          atc
left join tceArrTipoCreditoCreditoEst      atcc on atcc.idtcearrtipocreditoest = atc.idtcearrtipocreditoest
left join tribCreditoContribuinteItem   tcci on tcci.idcreditocontribuinteitem = atcc.idcreditocontribuinteitem and tcci.iddebitoparcelareceita = atcc.iddebitoparcelareceita
left join tribcreditocontribuinte       tcc  on tcc.entidade = tcci.entidade and tcc.exercicio = tcci.exercicio and tcc.creditocontribuinte = tcci.creditocontribuinte
left join tribdebitoparcelareceita      tdpr on tdpr.iddebitoparcelareceita  = tcci.iddebitoparcelareceita
left join tribdebitoparcela             tdp  on tdp.entidade = tdpr.entidade and tdp.exercicio = tdpr.exercicio and tdp.tipocadastro = tdpr.tipocadastro
                                            and tdp.cadastrogeral = tdpr.cadastrogeral and tdp.guiarecolhimento = tdpr.guiarecolhimento
                                            and tdp.subdivida = tdpr.subdivida and tdp.parcela = tdpr.parcela
left join tcedebitolanccreditoEst          tdlc on tdlc.iddebitoparcelareceita = atcc.iddebitoparcelareceita
left join tcelanccreditoEst                tlc  on tlc.idtcelanccreditoest = tdlc.idtcelanccreditoest
left join (select distinct a.idtceinsccreditodaest, a.iddebitoparcelareceita from tcedebitoinsccreditodaest a) tdic on tdic.iddebitoparcelareceita = atcc.iddebitoparcelareceita
left join tceinsccreditodaEst              tid  on tid.idtceinsccreditodaest = tdic.idtceinsccreditodaest
where tcc.entidade = :entidade and tcc.datacredito between :dataInicial and :dataFinal
) x
group by x.idtcearrtipocreditoest,
       x.nrAnoArrecadacao,
       x.nrCredito,
       x.nranocredito,
       x.nrdivida,
       x.nranodivida,
       x.nrMes,
       x.nrAno,
       x.dtestorno
order by 2,1
